==> ejc-bfyjerp-api-3.0.0-20250410.073645-193-sources.jar: com/ejianc/business/oa/vo/PurchaseDetailVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 人力行政-采购申请单子表
 * 
 * @author generator
 * 
 */
public class PurchaseDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long purchaseId; // 采购申请单主表id
    private Long detailStoreId; // 仓库id
    private String detailStoreName; // 仓库名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date detailApplyDate; // 申请日期
    private Long materialCategoryId; // 物资分类id
    private String materialCategoryName; // 物资分类名称
    private Long materialId; // 物资id
    private String materialCode; // 物资编码
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private String materialUnit; // 计量单位
    private BigDecimal number; // 入库数量
    private BigDecimal price; // 单价
    private BigDecimal rate; // 税率
    private BigDecimal amount; // 金额
    private String remark; // 备注
    

    public Long getPurchaseId() {
        return purchaseId;
    }

    public void setPurchaseId(Long purchaseId) {
        this.purchaseId = purchaseId;
    }
    public Long getDetailStoreId() {
        return detailStoreId;
    }

    public void setDetailStoreId(Long detailStoreId) {
        this.detailStoreId = detailStoreId;
    }
    public String getDetailStoreName() {
        return detailStoreName;
    }

    public void setDetailStoreName(String detailStoreName) {
        this.detailStoreName = detailStoreName;
    }
    public Date getDetailApplyDate() {
        return detailApplyDate;
    }

    public void setDetailApplyDate(Date detailApplyDate) {
        this.detailApplyDate = detailApplyDate;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public BigDecimal getNumber() {
        return number;
    }

    public void setNumber(BigDecimal number) {
        this.number = number;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250430.080838-215-sources.jar: com/ejianc/business/oa/vo/PurchaseDetailVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 人力行政-采购申请单子表
 * 
 * @author generator
 * 
 */
public class PurchaseDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long purchaseId; // 采购申请单主表id
    private Long detailStoreId; // 仓库id
    private String detailStoreName; // 仓库名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date detailApplyDate; // 申请日期
    private Long materialCategoryId; // 物资分类id
    private String materialCategoryName; // 物资分类名称
    private Long materialId; // 物资id
    private String materialCode; // 物资编码
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private String materialUnit; // 计量单位
    private BigDecimal number; // 入库数量
    private BigDecimal price; // 单价
    private BigDecimal rate; // 税率
    private BigDecimal amount; // 金额
    private String remark; // 备注
    private BigDecimal sumNum;//现有库存数量
    private BigDecimal num;//上次购买数量
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date time ;//上次购买时间
    private Long sourceId; // 来源id

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public Date getTime() {
        return time;
    }

    public void setTime(Date time) {
        this.time = time;
    }

    public Long getPurchaseId() {
        return purchaseId;
    }

    public void setPurchaseId(Long purchaseId) {
        this.purchaseId = purchaseId;
    }
    public Long getDetailStoreId() {
        return detailStoreId;
    }

    public void setDetailStoreId(Long detailStoreId) {
        this.detailStoreId = detailStoreId;
    }
    public String getDetailStoreName() {
        return detailStoreName;
    }

    public void setDetailStoreName(String detailStoreName) {
        this.detailStoreName = detailStoreName;
    }
    public Date getDetailApplyDate() {
        return detailApplyDate;
    }

    public void setDetailApplyDate(Date detailApplyDate) {
        this.detailApplyDate = detailApplyDate;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public BigDecimal getNumber() {
        return number;
    }

    public void setNumber(BigDecimal number) {
        this.number = number;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}
